issue_errors = r"""
        (
            (
                For\s+our\s+resolution
            )|
            (
                For\s+the\s+resolution\s+of\s+this\s+Court\s+then
            )|
            (
                For\s+this\s+Court[’']s\s+resolution
            )|
            (
                [Aa]ppellants?\s+assign
                (
                    s|ed
                )?
            )|
            (
                asked\s+to\s+resolve
            )|
            (
                anchored\s+on
            )|
            (
                based\s+on
            )|
            (
                submit # submits, submitted, submitting
                (
                    s|
                    ted|
                    ting
                )
            )|
            (
                rais # raise, raises, raised, raising
                (
                    e|
                    es|
                    ed|
                    ing
                )
            )|
            (
                present # presents, presented, presenting
                (
                    es|
                    ed|
                    ing
                )
            )
        )
        \s+
        (
            (
                are|
                is
            )\s+
        )?
        the\s+
        (
            (
                following|
                sole|
                lone
            )\s+
        )?
        (as\s+)?
        (
            (issues?)|
            (assigned\s+errors?)|
            (errors?)|
            (assignments?\s+of\s+errors?)|
            (arguments?)
        )
        \:?
    """
