main_issue = r"""
        (
            (^\s* # possible space before "The|Thus"
                (
                    The|
                    Thus,\s+the|
                )
            )|
            (
                raising\s+
                the
            )|
            (
                may\s+
                be\s+
                reduced\s+
                to
            )|
            (
                for\s+
                Our\s+
                consideration
                ,
            )|
            Apparently,|
            Appropriately,|
            Essentially,|
            Basically,|
            Simply,
        )\s+
        (the\s+)?
        (
            principal|
            threshold|
            core|
            pivotal|
            sole|
            main
        )\s+
        (
            issue|
            question
        )
    """
