granted_denied = r"""
        ^\s* # possible space before "The"
        (
            The|
            Appellants\’|
            [A-Z][a-z]+\’s # Amistoso's
        )
        \s+
        (
            recourse|
            appeals?|
            petitions?|
            contentions?
        )
        \s+
        (
            is|
            are|
            must
        )
        \s+
        (
            fail|
            baseless|
            denied|
            (
                without|
                (
                    (not\s+)?
                    impressed
                    \s+
                    with
                )|
                (
                    bereft
                    \s+
                    of
                )
                \s+
                merit
            )|
            (
                (
                    partly\s+
                )?
                granted
            )|
            (
                (
                    un|
                    partly\s+
                )?
                meritorious
            )
        )
    """
