court_admin = r"""
        ^\s* # possible space before "The"?
        (
            (The\s+Court)|
            (After\s+a\s+careful\s+review\s+of\s+the\s+records\s+of\s+this\s+case,\s+the\s+Court)|
            We
        )\s+
        (
            (find\s+no\s+reason\s+to\s+disturb)|
            (are\s+in\s+full\s+accord)|
            (note\s+and\s+adopt)|
            (see\s+no\s+reason\s+to\s+depart\s+from)|
            agrees?|
            (agrees?\s+and\s+adopts?)|
            (agrees?\s+with,\s+and\s+adopts?)|
            adopts?|
            (adopts?\s+and\s+agrees?)|
            concurs?|
            approve
        )\s+
        (in\s+toto\s+)?
        (with\s+)?
        (the\s+)?
        (
            (
                findings?\s+
                (and\s+recommendations?\s+)?
            )|
            (
                recommendations?\s+
            )|
            (
                foregoing\s+observations\s+
            )|
            (
                findings?\s+
                (and\s+conclusions?\s+)?
            )
        )?
        (
            of
            ,?
            \s+
        )?
        (the\s+)?
        (
            IBP|
            OCA|
            (
                (
                    Office\s+of\s+the\s+
                )?
                Court\s+Administrator
            )
        )
        (
            's\s+
            (
                findings?\s+
                (and\s+recommendations?\s+)?
            )|
            (
                recommendations?\s+
            )
        )?
    """
