merit = r"""
        ^\s* # possible space before "The"
        Th(e|is)\s+
        (
            appeal|
            petition|
            argument
        )\s+
        (
            lacks|
            has\s+no|
            (is\s+
                (
                    without|
                    devoid\s+of|
                    bereft\s+of
                )
            )
        )\s+
        merit
    """
